﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Activities.Presentation;
using System.Activities.Core.Presentation;
using System.Activities.Presentation.Toolbox;
using System.Activities.Statements;

namespace LoanProcessing
{
    /// <summary>
    /// Interaction logic for EditWorkflow.xaml
    /// </summary>
    public partial class EditWorkflow : Window
    {
        WorkflowDesigner designer = new WorkflowDesigner();
        const string WORKFLOW_FILE = @"..\..\LoanApplicationWorkflow.Xaml";

        public EditWorkflow()
        {
            InitializeComponent();

            CommandBindings.Add(new CommandBinding(Commands.Exit, OnCancel));
            CommandBindings.Add(new CommandBinding(Commands.Submit, OnSave));

            ToolboxControl toolbox = BuildToolbox();
            DockPanel.SetDock(toolbox, Dock.Left);
            mainLayout.Children.Add(toolbox);

            DockPanel.SetDock(designer.PropertyInspectorView, Dock.Right);
            mainLayout.Children.Add(designer.PropertyInspectorView);

            mainLayout.Children.Add(designer.View);
            
            (new DesignerMetadata()).Register();

            designer.Load(WORKFLOW_FILE);

        }

        void OnCancel(object sender, RoutedEventArgs e)
        {
            this.Close();
        }

        void OnSave(object sender, RoutedEventArgs e)
        {
            designer.Save(WORKFLOW_FILE);
        }

        private ToolboxControl BuildToolbox()
        {
            ToolboxControl toolbox = new ToolboxControl();

            ToolboxCategory loanCategory = new ToolboxCategory("Loan Activities");
            loanCategory.Add(new ToolboxItemWrapper(typeof(GetStandardRate)));
            loanCategory.Add(new ToolboxItemWrapper(typeof(GetPremiumRate)));
            loanCategory.Add(new ToolboxItemWrapper(typeof(Approve)));
            loanCategory.Add(new ToolboxItemWrapper(typeof(Reject)));
            loanCategory.Add(new ToolboxItemWrapper(typeof(SendForManualApproval)));
            loanCategory.Add(new ToolboxItemWrapper(typeof(CalculateRepayment)));

            ToolboxCategory stdCategory = new ToolboxCategory("Standard Activities");
            stdCategory.Add(new ToolboxItemWrapper(typeof(FlowDecision)));
            stdCategory.Add(new ToolboxItemWrapper(typeof(Assign)));

            toolbox.Categories.Add(loanCategory);
            toolbox.Categories.Add(stdCategory);
            return toolbox;
        }
    }
}
