﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Activities;
using System.IO;

namespace LoanProcessing
{
    public class SendForManualApproval : CodeActivity
    {
        protected override void Execute(CodeActivityContext context)
        {
            TextWriter tw = context.GetExtension<TextWriter>();

            if (tw == null)
            {
                tw = Console.Out;
            }

            tw.WriteLine("Sending application for manual approval");
        }
    }


    public class Reject : CodeActivity
    {
        protected override void Execute(CodeActivityContext context)
        {
            TextWriter tw = context.GetExtension<TextWriter>();

            if (tw == null)
            {
                tw = Console.Out;
            }

            tw.WriteLine("Rejecting application");
        }
    }


    public class Approve : CodeActivity
    {
        protected override void Execute(CodeActivityContext context)
        {
            TextWriter tw = context.GetExtension<TextWriter>();

            if (tw == null)
            {
                tw = Console.Out;
            }

            tw.WriteLine("Approving application");
        }
    }


    public class CalculateRepayment : CodeActivity
    {
        public InArgument<int> Amount { get; set; }
        public InArgument<int> Term { get; set; }
        public InArgument<double> Rate { get; set; }
        public OutArgument<double> MonthlyRepayment { get; set; }

        protected override void Execute(CodeActivityContext context)
        {
            TextWriter tw = context.GetExtension<TextWriter>();

            if (tw == null)
            {
                tw = Console.Out;
            }

            double rateFactor = 1 + (Rate.Get(context) / 100);
            double termYears = (double)Term.Get(context) / 12.0;

            double totalRepayment = Amount.Get(context) * Math.Pow(rateFactor, termYears);

            MonthlyRepayment.Set(context, totalRepayment / (double)Term.Get(context));

            tw.WriteLine("Calculating repayment at %{0} on {1}", Rate.Get(context), Amount.Get(context));
        }
    }

    public class GetStandardRate : CodeActivity
    {
        public OutArgument<double> Rate { get; set; }
        protected override void Execute(CodeActivityContext context)
        {
            TextWriter tw = context.GetExtension<TextWriter>();

            if (tw == null)
            {
                tw = Console.Out;
            }

            double rate = 7.0;

            Rate.Set(context, rate);

            tw.WriteLine("Getting standard rate at %{0}", rate);
        }
    }

    public class GetPremiumRate : CodeActivity
    {
        public OutArgument<double> Rate { get; set; }
        protected override void Execute(CodeActivityContext context)
        {
            TextWriter tw = context.GetExtension<TextWriter>();

            if (tw == null)
            {
                tw = Console.Out;
            }

            double rate = 11.0;

            Rate.Set(context, rate);

            tw.WriteLine("Getting standard rate at %{0}", rate);
        }
    }

}
