﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Activities.XamlIntegration;
using System.Activities;
using System.IO;

namespace LoanProcessing
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private LoanDetails details = new LoanDetails();
        private LoanStatus status = new LoanStatus();

        public MainWindow()
        {
            InitializeComponent();

            loanDetails.DataContext = details;
            statusBar.DataContext = status;

            CommandBindings.Add(new CommandBinding(Commands.Exit, OnExit));
            CommandBindings.Add(new CommandBinding(Commands.EditWorkflow, OnEditWorkflow));
            CommandBindings.Add(new CommandBinding(Commands.Submit, OnSubmit));
        }

        private void OnExit(object sender, RoutedEventArgs e)
        {
            this.Close();
        }

        private void OnEditWorkflow(object sender, RoutedEventArgs e)
        {
            var editor = new EditWorkflow();

            editor.ShowDialog();
        }

        private void OnSubmit(object sender, RoutedEventArgs e)
        {
            Activity workflow = ActivityXamlServices.Load(@"..\..\LoanApplicationWorkflow.xaml");

            var inputs = new Dictionary<string, object>()
            {
                {"Amount", details.Amount},
                {"Term", details.Term},
                {"CreditRate", details.CreditRating}
            };

            WorkflowInvoker invoker = new WorkflowInvoker(workflow);

            StringWriter writer = new StringWriter();
            invoker.Extensions.Add(writer);

            var outputs = invoker.Invoke(inputs);

            statusBar.DataContext = new LoanStatus
            {
                Status = (ApprovalStatus)outputs["ApprovalStatus"],
                MonthlyRepayment = (double)outputs["MonthlyRepayment"]
            };

            output.Text = writer.ToString();
        }

    }
}
